@@ -120,11 +120,12 @@ sys.excepthook = handle_all_unhandled_exceptions
 
 
 async def test_order_book(exchange, symbol):
-    if exchange.has['fetchOrderBook']:
+    method = 'fetchOrderBook'
+    if exchange.has[method]:
         delay = int(exchange.rateLimit / 1000)
         await asyncio.sleep(delay)
         # dump(green(exchange.id), green(symbol), 'fetching order book...')
-        orderbook = await exchange.fetch_order_book(symbol)
+        orderbook = await getattr(exchange, method)(symbol)
         dump(
             green(exchange.id),
             green(symbol),
@@ -135,12 +136,13 @@ async def test_order_book(exchange, symbol):
             'ask: ' + str(orderbook['asks'][0][0] if len(orderbook['asks']) else 'N/A'),
             'askVolume: ' + str(orderbook['asks'][0][1] if len(orderbook['asks']) else 'N/A'))
     else:
-        dump(yellow(exchange.id), 'fetch_order_book() supported')
+        dump(yellow(exchange.id), method + '() is not supported')
 
 # ------------------------------------------------------------------------------
 
 
 async def test_ohlcvs(exchange, symbol):
+    method = 'fetchOHLCV'
     ignored_exchanges = [
         'cex',  # CEX can return historical candles for a certain date only
         'okex',  # okex fetchOHLCV counts "limit" candles from current time backwards
@@ -148,7 +150,7 @@ async def test_ohlcvs(exchange, symbol):
     ]
     if exchange.id in ignored_exchanges:
         return
-    if exchange.has['fetchOHLCV']:
+    if exchange.has[method]:
         delay = int(exchange.rateLimit / 1000)
         await asyncio.sleep(delay)
         timeframes = exchange.timeframes if exchange.timeframes else {'1d': '1d'}
@@ -156,29 +158,30 @@ async def test_ohlcvs(exchange, symbol):
         limit = 10
         duration = exchange.parse_timeframe(timeframe)
         since = exchange.milliseconds() - duration * limit * 1000 - 1000
-        ohlcvs = await exchange.fetch_ohlcv(symbol, timeframe, since, limit)
+        ohlcvs = await getattr(exchange, method)(symbol, timeframe, since, limit)
         for ohlcv in ohlcvs:
             test_ohlcv(exchange, ohlcv, symbol, int(time.time() * 1000))
         dump(green(exchange.id), 'fetched', green(len(ohlcvs)), 'OHLCVs')
     else:
-        dump(yellow(exchange.id), 'fetching OHLCV not supported')
+        dump(yellow(exchange.id), method + '() is not supported')
 
 # ------------------------------------------------------------------------------
 
 
 async def test_tickers(exchange, symbol):
+    method = 'fetchTickers'
     ignored_exchanges = [
         'digifinex',  # requires apiKey to call v2 tickers
     ]
     if exchange.id in ignored_exchanges:
         return
-    if exchange.has['fetchTickers']:
+    if exchange.has[method]:
         delay = int(exchange.rateLimit / 1000)
         await asyncio.sleep(delay)
         tickers = None
         try:
             # dump(green(exchange.id), 'fetching all tickers at once...')
-            tickers = await exchange.fetch_tickers()
+            tickers = await getattr(exchange, method)()
             dump(green(exchange.id), 'fetched all', green(len(list(tickers.keys()))), 'tickers')
         except Exception as e:
             dump(green(exchange.id), 'failed to fetch all tickers, fetching multiple tickers at once...')
@@ -228,15 +231,16 @@ async def test_l2_order_books_async(exchange):
 
 
 async def test_ticker(exchange, symbol):
+    method = 'fetchTicker'
     ignored_exchanges = [
         'digifinex',  # requires apiKey to call v2 tickers
     ]
     if exchange.id in ignored_exchanges:
         return
-    if exchange.has['fetchTicker']:
+    if exchange.has[method]:
         delay = int(exchange.rateLimit / 1000)
         await asyncio.sleep(delay)
-        ticker = await exchange.fetch_ticker(symbol)
+        ticker = await getattr(exchange, method)(symbol)
         dump(
             green(exchange.id),
             green(symbol),
@@ -248,34 +252,36 @@ async def test_ticker(exchange, symbol):
             'ask: ' + str(ticker['ask']),
             'volume: ' + str(ticker['quoteVolume']))
     else:
-        dump(green(exchange.id), green(symbol), 'fetch_ticker() not supported')
+        dump(green(exchange.id), green(symbol), method + '() is not supported')
 
 # ------------------------------------------------------------------------------
 
 
 async def test_trades(exchange, symbol):
-    if exchange.has['fetchTrades']:
+    method = 'fetchTrades'
+    if exchange.has[method]:
         delay = int(exchange.rateLimit / 1000)
         await asyncio.sleep(delay)
         # dump(green(exchange.id), green(symbol), 'fetching trades...')
-        trades = await exchange.fetch_trades(symbol)
+        trades = await getattr(exchange, method)(symbol)
         if trades:
             test_trade(exchange, trades[0], symbol, int(time.time() * 1000))
         dump(green(exchange.id), green(symbol), 'fetched', green(len(trades)), 'trades')
     else:
-        dump(green(exchange.id), green(symbol), 'fetch_trades() not supported')
+        dump(green(exchange.id), green(symbol), method + '() is not supported')
 
 # ------------------------------------------------------------------------------
 
 
 async def test_orders(exchange, symbol):
-    if exchange.has['fetchOrders']:
+    method = 'fetchOrders'
+    if exchange.has[method]:
         skipped_exchanges = [
             'bitmart',
             'rightbtc',
         ]
         if exchange.id in skipped_exchanges:
-            dump(green(exchange.id), green(symbol), 'fetch_orders() skipped')
+            dump(green(exchange.id), green(symbol), method + '() skipped')
             return
         delay = int(exchange.rateLimit / 1000)
         await asyncio.sleep(delay)
@@ -285,74 +291,100 @@ async def test_orders(exchange, symbol):
             test_order(exchange, order, symbol, int(time.time() * 1000))
         dump(green(exchange.id), green(symbol), 'fetched', green(len(orders)), 'orders')
     else:
-        dump(green(exchange.id), green(symbol), 'fetch_orders() not supported')
+        dump(green(exchange.id), green(symbol), method + '() is not supported')
 
 # ------------------------------------------------------------------------------
 
 
 async def test_positions(exchange, symbol):
-    if exchange.has['fetchPositions']:
+    method = 'fetchPositions'
+    if exchange.has[method]:
         skipped_exchanges = [
         ]
         if exchange.id in skipped_exchanges:
-            dump(green(exchange.id), green(symbol), 'fetch_positions() skipped')
+            dump(green(exchange.id), green(symbol), method + '() skipped')
             return
         delay = int(exchange.rateLimit / 1000)
         await asyncio.sleep(delay)
-        # dump(green(exchange.id), green(symbol), 'fetching positions...')
-        positions = await exchange.fetch_positions()
+        # without symbol
+        dump(green(exchange.id), 'fetching positions...')
+        positions = await getattr(exchange, method)()
+        for position in positions:
+            test_position(exchange, position, None, int(time.time() * 1000))
+        dump(green(exchange.id), 'fetched', green(len(positions)), 'positions')
+
+        # with symbol
+        dump(green(exchange.id), green(symbol), 'fetching positions...')
+        positions = await getattr(exchange, method)([symbol])
         for position in positions:
             test_position(exchange, position, symbol, int(time.time() * 1000))
         dump(green(exchange.id), green(symbol), 'fetched', green(len(positions)), 'positions')
     else:
-        dump(green(exchange.id), green(symbol), 'fetch_positions() not supported')
+        dump(green(exchange.id), green(symbol), method + '() is not supported')
 
 # ------------------------------------------------------------------------------
 
 
 async def test_closed_orders(exchange, symbol):
-    if exchange.has['fetchClosedOrders']:
+    method = 'fetchClosedOrders'
+    if exchange.has[method]:
         delay = int(exchange.rateLimit / 1000)
         await asyncio.sleep(delay)
         # dump(green(exchange.id), green(symbol), 'fetching orders...')
-        orders = await exchange.fetch_closed_orders(symbol)
+        orders = await getattr(exchange, method)(symbol)
         for order in orders:
             test_order(exchange, order, symbol, int(time.time() * 1000))
             assert order['status'] == 'closed' or order['status'] == 'canceled'
         dump(green(exchange.id), green(symbol), 'fetched', green(len(orders)), 'closed orders')
     else:
-        dump(green(exchange.id), green(symbol), 'fetch_closed_orders() not supported')
+        dump(green(exchange.id), green(symbol), method + '() is not supported')
 
 # ------------------------------------------------------------------------------
 
 
 async def test_open_orders(exchange, symbol):
-    if exchange.has['fetchOpenOrders']:
+    method = 'fetchOpenOrders'
+    if exchange.has[method]:
         delay = int(exchange.rateLimit / 1000)
         await asyncio.sleep(delay)
         # dump(green(exchange.id), green(symbol), 'fetching orders...')
-        orders = await exchange.fetch_open_orders(symbol)
+        orders = await getattr(exchange, method)(symbol)
         for order in orders:
             test_order(exchange, order, symbol, int(time.time() * 1000))
             assert order['status'] == 'open'
         dump(green(exchange.id), green(symbol), 'fetched', green(len(orders)), 'open orders')
     else:
-        dump(green(exchange.id), green(symbol), 'fetch_open_orders() not supported')
+        dump(green(exchange.id), green(symbol), method + '() is not supported')
 
 # ------------------------------------------------------------------------------
 
 
 async def test_transactions(exchange, code):
-    if exchange.has['fetchTransactions']:
+    method = 'fetchTransactions'
+    if exchange.has[method]:
         delay = int(exchange.rateLimit / 1000)
         await asyncio.sleep(delay)
 
-        transactions = await exchange.fetch_transactions(code)
+        transactions = await getattr(exchange, method)(code)
         for transaction in transactions:
             test_transaction(exchange, transaction, code, int(time.time() * 1000))
         dump(green(exchange.id), green(code), 'fetched', green(len(transactions)), 'transactions')
     else:
-        dump(green(exchange.id), green(code), 'fetch_transactions() not supported')
+        dump(green(exchange.id), green(code), method + '() is not supported')
+
+# ------------------------------------------------------------------------------
+
+
+async def test_balance(exchange):
+    method = 'fetchBalance'
+    if exchange.has[method]:
+        delay = int(exchange.rateLimit / 1000)
+        await asyncio.sleep(delay)
+
+        await getattr(exchange, method)()
+        dump(green(exchange.id), 'fetched balance')
+    else:
+        dump(green(exchange.id), method + '() is not supported')
 
 # ------------------------------------------------------------------------------
 
@@ -360,26 +392,39 @@ async def test_transactions(exchange, code):
 async def test_symbol(exchange, symbol, code):
     dump(green('SYMBOL: ' + symbol))
     dump(green('CODE: ' + code))
+    dump('Testing fetch_ticker:' + symbol)
     await test_ticker(exchange, symbol)
+    dump('Testing fetch_tickers:' + symbol)
     await test_tickers(exchange, symbol)
+    dump('Testing fetch_ohlcv:' + symbol)
     await test_ohlcvs(exchange, symbol)
 
     if exchange.id == 'coinmarketcap':
         response = await exchange.fetchGlobal()
         dump(green(response))
     else:
+        dump('Testing fetch_order_book:' + symbol)
         await test_order_book(exchange, symbol)
+        dump('Testing fetch_trades:' + symbol)
         await test_trades(exchange, symbol)
         if (not hasattr(exchange, 'apiKey') or (len(exchange.apiKey) < 1)):
             return
-        if exchange.has['signIn']:
-            await exchange.sign_in()
+        method = 'signIn'
+        if exchange.has[method]:
+            dump('Testing ' + method + '()')
+            await getattr(exchange, method)()
+        dump('Testing fetch_orders:' + symbol)
         await test_orders(exchange, symbol)
+        dump('Testing fetch_open_orders:' + symbol)
         await test_open_orders(exchange, symbol)
+        dump('Testing fetch_closed_orders:' + symbol)
         await test_closed_orders(exchange, symbol)
+        dump('Testing fetch_transactions:' + code)
         await test_transactions(exchange, code)
-        await exchange.fetch_balance()
-        dump(green(exchange.id), 'fetched balance')
+        dump('Testing fetch_balance')
+        await test_balance(exchange)
+        dump('Testing fetch_positions:' + symbol)
+        await test_positions(exchange, symbol)
 
 # ------------------------------------------------------------------------------
 
@@ -396,6 +441,7 @@ def get_test_symbol(exchange, symbols):
             active = exchange.safe_value(market, 'active')
             if active or (active is None):
                 symbol = s
+                break
     return symbol
 
 
@@ -457,6 +503,7 @@ async def test_exchange(exchange, symbol=None):
             'BTC/JPY',
             'LTC/BTC',
             'USD/SLL',
+            'EUR/USD',
         ])
 
         if symbol is None:
@@ -550,7 +597,6 @@ async def try_all_proxies(exchange, proxies=['']):
 proxies = [
     '',
     'https://cors-anywhere.herokuapp.com/',
-    # 'https://crossorigin.me/',
 ]
 
 # prefer local testing keys to global keys
@@ -570,7 +616,7 @@ for id in ccxt.exchanges:
     exchange = getattr(ccxt, id)
     exchange_config = {'verbose': argv.verbose}
     if sys.version_info[0] < 3:
-        exchange_config.update({'enableRateLimit': True})
+        exchange_config.update()
     if id in config:
         exchange_config = ccxt.Exchange.deep_extend(exchange_config, config[id])
     exchanges[id] = exchange(exchange_config)
